@@ -18,20 +18,28 @@
 #ifndef __kbstate_h__
 #define __kbstate_h__
 
-#include <kpanelapplet.h> 
-#include <qpushbutton.h>
-#include <qptrlist.h>
-#include <qtimer.h>
+#include <k3panelapplet.h> 
+
+#include <QtGui/QPushButton>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QTimer>
+#include <QtGui/QPixmap>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QLabel>
+#include <QtCore/QTimerEvent>
+#include <QtGui/QGridLayout>
+#include <QtGui/QResizeEvent>
 
 extern "C"
 {
 #include <X11/Xlib.h>
 #include <X11/XKBlib.h>
 }
-     
+
 class QLabel;      
 class QGridLayout;
-class KPopupMenu;
+class KMenu;
+class KIconLoader;
 
 class StatusIcon : public QPushButton {
    Q_OBJECT
@@ -41,12 +49,12 @@ public:
 
    QSize minimumSizeHint () const;
 };
-typedef QPtrList<StatusIcon> IconList;
+typedef Q3PtrList<StatusIcon> IconList;
 
 class TimeoutIcon : public StatusIcon {
    Q_OBJECT
 public:
-   TimeoutIcon (KInstance *instance, const QString &text,
+   TimeoutIcon (KIconLoader *iconLoader, const QString &text,
 					 const QString &featurename,
 					 QWidget *parent, const char *name=0);
    ~TimeoutIcon ();
@@ -64,7 +72,7 @@ private:
    QPixmap pixmap;
    QPixmap image;
    QTimer timer;
-   KInstance *instance;
+   KIconLoader *iconLoader;
    
 private slots:
    void timeout ();
@@ -73,7 +81,7 @@ private slots:
 class KeyIcon : public StatusIcon {
    Q_OBJECT
 public:
-   KeyIcon (int keyId, KInstance *instance,
+   KeyIcon (int keyId, KIconLoader *iconLoader,
             QWidget *parent, const char *name=0);
    ~KeyIcon ();
    void setState (bool latched, bool locked);
@@ -97,13 +105,13 @@ private:
    bool    isLocked;
    bool    tristate;
    int     keyId;
-   KInstance *instance;
+   KIconLoader *iconLoader;
 };
 
 class MouseIcon : public StatusIcon {
 	Q_OBJECT
 	public:
-		MouseIcon (KInstance *instance, QWidget *parent, const char *name=0);
+		MouseIcon (KIconLoader *iconLoader, QWidget *parent, const char *name=0);
 		~MouseIcon ();
 		void setState (int state);
 		void setActiveKey (int activekey);
@@ -125,14 +133,14 @@ class MouseIcon : public StatusIcon {
 		QPixmap middleDotSelected;
 		QPixmap rightDotSelected;
 		int state, activekey;
-		KInstance *instance;
+		KIconLoader *iconLoader;
 };
 
-class KbStateApplet : public KPanelApplet {
+class KbStateApplet : public K3PanelApplet {
    Q_OBJECT
 
 public:
-   KbStateApplet(const QString& configFile, Type t = Normal, int actions = 0,
+   explicit KbStateApplet(const QString& configFile, K3PanelApplet::Type t = K3PanelApplet::Normal, int actions = 0,
               QWidget *parent = 0, const char *name = 0);
    ~KbStateApplet();
 
@@ -185,16 +193,17 @@ private:
 
    void buildPopupMenu();
    void updateMenu();
-   KPopupMenu *popup;
-   KPopupMenu *sizePopup;
-   KPopupMenu *showPopup;
+   KMenu *popup;
+   KMenu *sizePopup;
+   KMenu *showPopup;
 	int modifierItem, lockkeysItem, mouseItem, accessxItem;
 	int fillSpaceItem;
 	bool showModifiers, showLockkeys, showMouse, showAccessX;
 	bool fillSpace;
 
-	KInstance *instance;
+	KComponentData componentData;
 	XkbDescPtr xkb;
+	KIconLoader *m_iconLoader;
 };
 
 #endif // __kbstate_h__
