@@ -22,28 +22,27 @@
 #ifndef KMOUSETOOL_H
 #define KMOUSETOOL_H
 
-#include <qdir.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include <QtCore/QDir>
+#include <QtGui/QLabel>
+#include <QtCore/QTimerEvent>
+#include <QtGui/QWidget>
 
 #include "version.h"
 
-#include <kapplication.h>
-#include <ksystemtray.h>
-#include <qwidget.h>
+#include <ksystemtrayicon.h>
 #include "mtstroke.h"
-#include "kmousetoolui.h"
+#include "ui_kmousetoolui.h"
 
-class QLineEdit;
 class QLabel;
-class QCheckBox;
-class QPushButton;
+class QAction;
 class KAudioPlayer;
-class KAboutApplication;
+class KAboutApplicationDialog;
 class KMouseToolTray;
 
+namespace Phonon
+{
+      class MediaObject;
+}
 
 /**
  * KMouseTool is the base class of the project
@@ -52,7 +51,7 @@ class KMouseToolTray;
  *
  */
 
-class KMouseTool : public KMouseToolUI
+class KMouseTool : public QWidget, public Ui::KMouseToolUI
 {
 	Q_OBJECT
 
@@ -78,10 +77,10 @@ private:
 	QString rcfilename;
 	QString appfilename;
 	QString	mSoundFileName;
-	KAudioPlayer *mplayer;
+	Phonon::MediaObject *mplayer;
 	KMouseToolTray *trayIcon;
 
-	KAboutApplication *aboutDlg;
+	KAboutApplicationDialog *aboutDlg;
 
 	/**
 	 * Initialize all variables
@@ -186,17 +185,17 @@ public:
 	/**
 	 *  construtor
 	 */
-	KMouseTool(QWidget* parent=0, const char *name=0);
+	explicit KMouseTool(QWidget* parent=0, const char *name=0);
 
 	/** destructor */
 	~KMouseTool();
 };
 
-class KMouseToolTray : public KSystemTray {
+class KMouseToolTray : public KSystemTrayIcon {
         Q_OBJECT
-	int startStopId;
+	QAction* startStopAct;
 public:
-	KMouseToolTray (QWidget *parent=0, const char *name=0);
+	explicit KMouseToolTray (QWidget *parent=0, const char *name=0);
 	~KMouseToolTray();
 
 	void updateStartStopText (bool mousetool_is_running);
