@@ -1,36 +1,17 @@
-/***************************************************** vim:set ts=4 sw=4 sts=4:
-  KTTSD Filter Test Program
-  -------------------------
-  Copyright:
-  (C) 2005 by Gary Cramblitt <garycramblitt@comcast.net>
-  -------------------
-  Original author: Gary Cramblitt <garycramblitt@comcast.net>
+/**********************
+  #FILENAME: #FILEDESC
+  #COPYRIGHTNOTICE
+  #LICENSE
+***********************/
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- ******************************************************************************/
-
-#include <qstring.h>
 #include <iostream>
 using namespace std;
 
-#include <qtextstream.h>
+#include <QtCore/QTextStream>
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kaboutdata.h>
-#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <ktrader.h>
@@ -39,34 +20,29 @@ using namespace std;
 #include "filterproc.h"
 #include "talkercode.h"
 
-static const KCmdLineOptions options[] =
-{
-    { "+pluginName", I18N_NOOP("Name of a KTTSD filter plugin (required)"), 0 },
-    { "t", 0, 0 },
-    { "talker <talker>", I18N_NOOP("Talker code passed to filter"), "en" }, 
-    { "a", 0, 0 },
-    { "appid <appID>", I18N_NOOP("DCOP application ID passed to filter"), "testfilter" },
-    { "g", 0, 0 },
-    { "group <filterID>",
-        I18N_NOOP2("A string that appears in a single config file, not a group of config files",
-            "Config file group name passed to filter"), "testfilter" },
-    { "list", I18N_NOOP("Display list of available Filter PlugIns and exit"), 0 },
-    { "b", 0, 0 },
-    { "break", I18N_NOOP("Display tabs as \\t, otherwise they are removed"), 0 },
-    { "list", I18N_NOOP("Display list of available filter plugins and exit"), 0 },
-    KCmdLineLastOption
-};
-
 int main(int argc, char *argv[])
 {
     KAboutData aboutdata(
-        "testfilter", I18N_NOOP("testfilter"),
-        "0.1.0", I18N_NOOP("A utility for testing KTTSD filter plugins."),
-         KAboutData::License_GPL, "(C) 2005, Gary Cramblitt <garycramblitt@comcast.net>");
-    aboutdata.addAuthor("Gary Cramblitt", I18N_NOOP("Maintainer"),"garycramblitt@comcast.net");
+        "testfilter", 0, ki18n("testfilter"),
+        "0.1.0", ki18n("A utility for testing KTTSD filter plugins."),
+         KAboutData::License_GPL, ki18n("Copyright 2005, Gary Cramblitt <garycramblitt@comcast.net>"));
+    aboutdata.addAuthor(ki18n("Gary Cramblitt"), ki18n("Maintainer"),"garycramblitt@comcast.net");
 
     KCmdLineArgs::init( argc, argv, &aboutdata );
     // Tell which options are supported
+
+    KCmdLineOptions options;
+    options.add("+pluginName", ki18n("Name of a KTTSD filter plugin (required)"));
+    options.add("t");
+    options.add("talker <talker>", ki18n("Talker code passed to filter"), "en");
+    options.add("a");
+    options.add("appid <appID>", ki18n("DCOP application ID passed to filter"), "testfilter");
+    options.add("g");
+    options.add("group <filterID>", ki18n("Config file group name passed to filter"), "testfilter");
+    options.add("list", ki18n("Display list of available Filter PlugIns and exit"));
+    options.add("b");
+    options.add("break", ki18n("Display tabs as \\t, otherwise they are removed"));
+    options.add("list", ki18n("Display list of available filter plugins and exit"));
     KCmdLineArgs::addCmdLineOptions( options );
 
     KApplication app( false, false );
@@ -93,7 +69,7 @@ int main(int argc, char *argv[])
     QCString appId = args->getOption("appid");
     QString groupName = args->getOption("group");
 
-    if (filterName.isEmpty()) kdError(1) << "No filter name given." << endl;
+    if (filterName.isEmpty()) kError(1) << "No filter name given." << endl;
 
     const int offersCount = offers.count();
     for(int ndx=0; ndx < offersCount ; ++ndx)
@@ -109,7 +85,7 @@ int main(int argc, char *argv[])
                 // specific plug in to get the plug in configuration object.
                 int errorNo;
                 KttsFilterProc *plugIn =
-                    KParts::ComponentFactory::createInstanceFromLibrary<KttsFilterProc>(
+                    KLibLoader::createInstance<KttsFilterProc>(
                     offers[ndx]->library().latin1(), NULL, offers[ndx]->library().latin1(),
                         QStringList(), &errorNo);
                     if(plugIn)
@@ -117,7 +93,7 @@ int main(int argc, char *argv[])
                         KConfig* config = new KConfig("kttsdrc");
                         config->setGroup( "General" );
                         plugIn->init( config, groupName );
-                        QTextStream inp ( stdin,  IO_ReadOnly );
+                        QTextStream inp ( stdin,  QIODevice::ReadOnly );
                         QString text;
                         text = inp.read();
                         TalkerCode* talkerCode = new TalkerCode( talker );
@@ -131,10 +107,10 @@ int main(int argc, char *argv[])
                         delete plugIn;
                         return 0;
                     } else
-                        kdError(2) << "Unable to create instance from library." << endl;
+                        kError(2) << "Unable to create instance from library." << endl;
             } else
-                kdError(3) << "Unable to create factory." << endl;
+                kError(3) << "Unable to create factory." << endl;
         }
     }
-    kdError(4) << "Unable to find a plugin named " << filterName << endl;
+    kError(4) << "Unable to find a plugin named " << filterName << endl;
 }
