@@ -15,9 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qstring.h>
 #include <kdebug.h>
-#include <qcombobox.h>
+
+#include <QtGui/QComboBox>
 
 #include "utils.h"
 
@@ -36,14 +36,14 @@ KttsUtils::~KttsUtils() {
 */
 bool KttsUtils::hasRootElement(const QString &xmldoc, const QString &elementName) {
     // Strip all whitespace and go from there.
-    QString doc = xmldoc.simplifyWhiteSpace();
+    QString doc = xmldoc.simplified();
     // Take off the <?xml...?> if it exists
     if(doc.startsWith("<?xml")) {
         // Look for ?> and strip everything off from there to the start - effectively removing
         // <?xml...?>
-        int xmlStatementEnd = doc.find("?>");
+        int xmlStatementEnd = doc.indexOf("?>");
         if(xmlStatementEnd == -1) {
-            kdDebug() << "KttsUtils::hasRootElement: Bad XML file syntax\n";
+            kDebug() << "KttsUtils::hasRootElement: Bad XML file syntax\n";
             return false;
         }
         xmlStatementEnd += 2;  // len '?>' == 2
@@ -51,9 +51,9 @@ bool KttsUtils::hasRootElement(const QString &xmldoc, const QString &elementName
     }
     // Take off leading comments, if they exist.
     while(doc.startsWith("<!--") || doc.startsWith(" <!--")) {
-        int commentStatementEnd = doc.find("-->");
+        int commentStatementEnd = doc.indexOf("-->");
         if(commentStatementEnd == -1) {
-            kdDebug() << "KttsUtils::hasRootElement: Bad XML file syntax\n";
+            kDebug() << "KttsUtils::hasRootElement: Bad XML file syntax\n";
             return false;
         }
         commentStatementEnd += 3; // len '>' == 2
@@ -61,55 +61,55 @@ bool KttsUtils::hasRootElement(const QString &xmldoc, const QString &elementName
     }
     // Take off the doctype statement if it exists.
     while(doc.startsWith("<!DOCTYPE") || doc.startsWith(" <!DOCTYPE")) {
-        int doctypeStatementEnd = doc.find(">");
+        int doctypeStatementEnd = doc.indexOf(">");
         if(doctypeStatementEnd == -1) {
-            kdDebug() << "KttsUtils::hasRootElement: Bad XML file syntax\n";
+            kDebug() << "KttsUtils::hasRootElement: Bad XML file syntax\n";
             return false;
         }
         doctypeStatementEnd += 1; // len '>' == 2
         doc = doc.right(doc.length() - doctypeStatementEnd);
     }
     // We should (hopefully) be left with the root element.
-    return (doc.startsWith("<" + elementName) || doc.startsWith(" <" + elementName));
+    return (doc.startsWith('<' + elementName) || doc.startsWith(" <" + elementName));
 }
 
 /** 
  * Check if an XML document has a certain DOCTYPE.
  * @param xmldoc             The document to check for the doctype.
- * @param name               The doctype name to check for. Pass QString::null to not check the name.
- * @param publicId           The public ID to check for. Pass QString::null to not check the ID.
- * @param systemId           The system ID to check for. Pass QString::null to not check the ID.
+ * @param name               The doctype name to check for. Pass QString() to not check the name.
+ * @param publicId           The public ID to check for. Pass QString() to not check the ID.
+ * @param systemId           The system ID to check for. Pass QString() to not check the ID.
  * @returns                  True if the parameters match the doctype, false otherwise.
 */
 bool KttsUtils::hasDoctype(const QString &xmldoc, const QString &name/*, const QString &publicId, const QString &systemId*/) {
     // Strip all whitespace and go from there.
-    QString doc = xmldoc.stripWhiteSpace();
+    QString doc = xmldoc.trimmed();
     // Take off the <?xml...?> if it exists
     if(doc.startsWith("<?xml")) {
         // Look for ?> and strip everything off from there to the start - effectively removing
         // <?xml...?>
-        int xmlStatementEnd = doc.find("?>");
+        int xmlStatementEnd = doc.indexOf("?>");
         if(xmlStatementEnd == -1) {
-            kdDebug() << "KttsUtils::hasDoctype: Bad XML file syntax\n";
+            kDebug() << "KttsUtils::hasDoctype: Bad XML file syntax\n";
             return false;
         }
         xmlStatementEnd += 2;  // len '?>' == 2
         doc = doc.right(doc.length() - xmlStatementEnd);
-        doc = doc.stripWhiteSpace();
+        doc = doc.trimmed();
     }
     // Take off leading comments, if they exist.
     while(doc.startsWith("<!--")) {
-        int commentStatementEnd = doc.find("-->");
+        int commentStatementEnd = doc.indexOf("-->");
         if(commentStatementEnd == -1) {
-            kdDebug() << "KttsUtils::hasDoctype: Bad XML file syntax\n";
+            kDebug() << "KttsUtils::hasDoctype: Bad XML file syntax\n";
             return false;
         }
         commentStatementEnd += 3; // len '>' == 2
         doc = doc.right(doc.length() - commentStatementEnd);
-        doc = doc.stripWhiteSpace();
+        doc = doc.trimmed();
     }
     // Match the doctype statement if it exists.
-    // kdDebug() << "KttsUtils::hasDoctype: searching " << doc.left(20) << "... for " << "<!DOCTYPE " << name << endl;
+    // kDebug() << "KttsUtils::hasDoctype: searching " << doc.left(20) << "... for " << "<!DOCTYPE " << name;
     return (doc.startsWith("<!DOCTYPE " + name));
 }
 
@@ -122,11 +122,12 @@ bool KttsUtils::hasDoctype(const QString &xmldoc, const QString &name/*, const Q
     const int itemCount = cb->count();
     for (int ndx = 0; ndx < itemCount; ++ndx)
     {
-        if (cb->text(ndx) == text)
+        if (cb->itemText(ndx) == text)
         {
-            cb->setCurrentItem(ndx);
+            cb->setCurrentIndex(ndx);
             return;
         }
     }
 }
 
+#include "player.moc"
